@@ -1,4 +1,4 @@
 class SubredditDownloaderConfig:
-    DEFAULT_CATEGORIES = ["hot", "new", "rising",
+    DEFAULT_CATEGORIES = ["hot", "new", "random_rising", "rising",
                           "controversial", "top", "gilded"]
     DEFAULT_POST_LIMIT = None
\ No newline at end of file
